correctAnswerSemanticValue property
Announced by the MCQ widget for a correct selection (paired with the green color so the state is not color-only).
Implementation
final String correctAnswerSemanticValue;
Announced by the MCQ widget for a correct selection (paired with the green color so the state is not color-only).
final String correctAnswerSemanticValue;