HtmlTable class

A TABLE widget.

Inheritance
Available extensions

Constructors

HtmlTable({Border? border, bool borderCollapse = false, double borderSpacing = 0.0, required List<Widget> children, TextDirection textDirection = TextDirection.ltr, Key? key})
Creates a TABLE widget.
const

Properties

border Border?
The table border sides.
final
borderCollapse bool
Controls whether to collapse borders.
final
borderSpacing double
The gap between borders.
final
children List<Widget>
The widgets below this widget in the tree.
finalinherited
defaultHorizontalSpace SizedBox

Available on Widget, provided by the WidgetExtension extension

no setter
defaultVerticalSpace SizedBox

Available on Widget, provided by the WidgetExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textDirection TextDirection
Determines the order to lay children out horizontally.
final

Methods

center() Center

Available on Widget, provided by the WidgetExtension extension

createElement() MultiChildRenderObjectElement
RenderObjectWidgets always inflate to a RenderObjectElement subclass.
inherited
createRenderObject(BuildContext context) RenderObject
Creates an instance of the RenderObject class that this RenderObjectWidget represents, using the configuration described by this RenderObjectWidget.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
didUnmountRenderObject(covariant RenderObject renderObject) → void
This method is called when a RenderObject that was previously associated with this widget is removed from the render tree. The provided RenderObject will be of the same type as the one created by this widget's createRenderObject method.
inherited
lightGreyBackground({required BuildContext context}) Container

Available on Widget, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(GestureTapCallback callback, {VoidCallback? onLongPress}) InkWell

Available on Widget, provided by the WidgetExtension extension

padAll({double? value}) Padding

Available on Widget, provided by the WidgetExtension extension

padBottom({double? bottom}) Padding

Available on Widget, provided by the WidgetExtension extension

padHorizontal({double? horizontal}) Padding

Available on Widget, provided by the WidgetExtension extension

padLeft({double? left}) Padding

Available on Widget, provided by the WidgetExtension extension

padRight({double? right}) Padding

Available on Widget, provided by the WidgetExtension extension

padTop({double? top}) Padding

Available on Widget, provided by the WidgetExtension extension

padVertical({double? vertical}) Padding

Available on Widget, provided by the WidgetExtension extension

padZero() Padding

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateRenderObject(BuildContext context, covariant RenderObject renderObject) → void
Copies the configuration described by this RenderObjectWidget to the given RenderObject, which will be of the same type as returned by this object's createRenderObject.
override
visible(bool visible, {Widget? defaultWidget}) Widget

Available on Widget, provided by the WidgetExtension extension

set visibility

Operators

operator ==(Object other) bool
The equality operator.
inherited