semanticLabel property
Optional accessibility label announced when the preview is focused. Defaults to "Open link: ".
Implementation
final String? semanticLabel;
Optional accessibility label announced when the preview is focused. Defaults to "Open link: ".
final String? semanticLabel;