DropdownWidget<T> class

A generic single-select dropdown for any type T.

Pass itemToString to display non-String items.

Inheritance
Available extensions

Constructors

Properties

defaultHorizontalSpace SizedBox

Available on Widget, provided by the WidgetExtension extension

no setter
defaultVerticalSpace SizedBox

Available on Widget, provided by the WidgetExtension extension

no setter
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hintText String
getter/setter pair
icon Widget
getter/setter pair
initialSelectedValue ↔ T?
getter/setter pair
isIconButton bool
getter/setter pair
itemList List<T>
getter/setter pair
itemToString String Function(T)?
getter/setter pair
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed ↔ void Function(T?)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSelected bool
getter/setter pair

Methods

center() Center

Available on Widget, provided by the WidgetExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DropdownWidget<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lightGreyBackground({required BuildContext context}) Container

Available on Widget, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(GestureTapCallback callback, {VoidCallback? onLongPress}) InkWell

Available on Widget, provided by the WidgetExtension extension

padAll({double? value}) Padding

Available on Widget, provided by the WidgetExtension extension

padBottom({double? bottom}) Padding

Available on Widget, provided by the WidgetExtension extension

padHorizontal({double? horizontal}) Padding

Available on Widget, provided by the WidgetExtension extension

padLeft({double? left}) Padding

Available on Widget, provided by the WidgetExtension extension

padRight({double? right}) Padding

Available on Widget, provided by the WidgetExtension extension

padTop({double? top}) Padding

Available on Widget, provided by the WidgetExtension extension

padVertical({double? vertical}) Padding

Available on Widget, provided by the WidgetExtension extension

padZero() Padding

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool visible, {Widget? defaultWidget}) Widget

Available on Widget, provided by the WidgetExtension extension

set visibility

Operators

operator ==(Object other) bool
The equality operator.
inherited