obscureText property
When true the input is rendered as obscured dots (use for PIN
entry). Defaults to false.
Implementation
final bool obscureText;
When true the input is rendered as obscured dots (use for PIN
entry). Defaults to false.
final bool obscureText;