MCQAnswerConfig class

A single answer inside an MCQConfig.

Constructors

MCQAnswerConfig({required String id, required String answer, bool isCorrectAnswer = false, bool isSelected = false, bool isIncorrectAnswer = false})

Properties

answer String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isCorrectAnswer bool
final
isIncorrectAnswer bool
final
isSelected bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, String? answer, bool? isSelected, bool? isCorrectAnswer, bool? isIncorrectAnswer}) MCQAnswerConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited