MCQConfig class

Configuration for a single multiple-choice question rendered by McqWidget.

Constructors

MCQConfig({required String id, required String question, required List<MCQAnswerConfig> answers, int? questionNoToDisplay, bool isToSelectAnswer = true})

Properties

answers List<MCQAnswerConfig>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isToSelectAnswer bool
final
question String
final
questionNoToDisplay int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited