YoutubePlayerConfig class

Configuration for YoutubePlayerWidget — a YouTube URL plus an optional placeholder image shown before playback starts.

Constructors

YoutubePlayerConfig({String? youtubeUrl, String? placeHolderImage})

Properties

hashCode int
The hash code for this object.
no setterinherited
placeHolderImage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
youtubeUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited