ReadMoreText class

Add read more button to a long text

Inheritance
Available extensions

Constructors

ReadMoreText(String data, {Key? key, String trimExpandedText = ' read less', String trimCollapsedText = ' ...read more', Color? colorClickableText, int trimLength = 240, int trimLines = 2, TrimMode trimMode = TrimMode.Length, TextStyle? style, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, double? textScaleFactor, String? semanticsLabel})
const

Properties

colorClickableText Color?
final
data String
final
defaultHorizontalSpace SizedBox

Available on Widget, provided by the WidgetExtension extension

no setter
defaultVerticalSpace SizedBox

Available on Widget, provided by the WidgetExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
locale Locale?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel String?
final
style TextStyle?
final
textAlign TextAlign?
final
textDirection TextDirection?
final
textScaleFactor double?
final
trimCollapsedText String
final
trimExpandedText String
final
trimLength int
final
trimLines int
final
trimMode TrimMode
final

Methods

center() Center

Available on Widget, provided by the WidgetExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ReadMoreTextState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
lightGreyBackground({required BuildContext context}) Container

Available on Widget, provided by the WidgetExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(GestureTapCallback callback, {VoidCallback? onLongPress}) InkWell

Available on Widget, provided by the WidgetExtension extension

padAll({double? value}) Padding

Available on Widget, provided by the WidgetExtension extension

padBottom({double? bottom}) Padding

Available on Widget, provided by the WidgetExtension extension

padHorizontal({double? horizontal}) Padding

Available on Widget, provided by the WidgetExtension extension

padLeft({double? left}) Padding

Available on Widget, provided by the WidgetExtension extension

padRight({double? right}) Padding

Available on Widget, provided by the WidgetExtension extension

padTop({double? top}) Padding

Available on Widget, provided by the WidgetExtension extension

padVertical({double? vertical}) Padding

Available on Widget, provided by the WidgetExtension extension

padZero() Padding

Available on Widget, provided by the WidgetExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
visible(bool visible, {Widget? defaultWidget}) Widget

Available on Widget, provided by the WidgetExtension extension

set visibility

Operators

operator ==(Object other) bool
The equality operator.
inherited