onLinkTap property
Called when the user taps a link inside the rendered HTML. When
null, taps launch the URL in the default external handler via
url_launcher.
Implementation
final ValueChanged<String>? onLinkTap;
Called when the user taps a link inside the rendered HTML. When
null, taps launch the URL in the default external handler via
url_launcher.
final ValueChanged<String>? onLinkTap;