TextOptions class

Fine-grained style overrides for TextWidget.

Constructors

TextOptions({double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? height, double? letterSpacing, TextDecoration? decoration = TextDecoration.none, String? fontFamily})
const

Properties

decoration TextDecoration?
final
fontFamily String?
When set, overrides the library-wide UiFrameworkConfig.fontFamily.
final
fontSize double?
final
fontStyle FontStyle?
final
fontWeight FontWeight?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
letterSpacing double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited