DynamicMsgTitleConfig class

HTML title/description block placed above or below the image inside DynamicMessageWidget.

Constructors

DynamicMsgTitleConfig({required String title, bool isToDisplayAtTopPosition = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isToDisplayAtTopPosition bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited