DynamicMsgYoutubePlayerConfig class

Optional YouTube embed shown alongside title/description.

Constructors

DynamicMsgYoutubePlayerConfig({bool addSpaceToTop = false, bool addSpaceToBottom = false, String? youtubeUrl})

Properties

addSpaceToBottom bool
final
addSpaceToTop bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
youtubeUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited