LocalImageConfig class
Configuration for a leading icon shown next to a LabelConfig row.
Constructors
- LocalImageConfig({required String imagePath, double? imageHeight, double? imageWidth, double? padRight, double? padLeft, ColorModel? svgColor})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageHeight → double?
-
final
- imagePath → String
-
final
- imageWidth → double?
-
final
- padLeft → double?
-
final
- padRight → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- svgColor → ColorModel?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited