AppRadius class
Semantic corner-radius tokens for ui_framework_kit.
Constants are logical pixels; pair with .r from
flutter_screenutil for responsive scaling.
BorderRadius.circular(AppRadius.md.r)
AppRadius.lgRadius // pre-built BorderRadius.all(...)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- full → const double
- 9999 logical pixels — fully rounded (pill / circle).
- lg → const double
- 12 logical pixels — bottom sheets, large cards.
- lgRadius → const BorderRadius
-
Pre-built
BorderRadius.all(Radius.circular(lg)). - md → const double
- 8 logical pixels — default for cards, fields, buttons.
- mdRadius → const BorderRadius
-
Pre-built
BorderRadius.all(Radius.circular(md)). - sm → const double
- 4 logical pixels — chips, badges, small buttons.
- smRadius → const BorderRadius
-
Pre-built
BorderRadius.all(Radius.circular(sm)). - xl → const double
- 16 logical pixels — modal panels.
- xlRadius → const BorderRadius
-
Pre-built
BorderRadius.all(Radius.circular(xl)).