TextFieldWidget class
A pre-styled text field with theme-aware borders, password toggle, validation, and consistent label/hint behavior.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TextFieldWidget
- Available extensions
Constructors
-
TextFieldWidget({Key? key, String? validator(String? value)?, int? maxLines, TextStyle? textStyle, double? labelFontSize, VoidCallback? onTap, bool obscureText = false, TextAlign textAlign = TextAlign.start, bool enabled = true, VoidCallbackWithValue<
String> ? onSaved, VoidCallbackWithValue<String> ? onFieldSubmitted, VoidCallbackWithValue<String> ? onChanged, List<TextInputFormatter> ? inputFormatters, TextEditingController? controller, String? initialValue, TextInputType? keyboardType, int? minLines, int? maxLength, bool readOnly = false, InputDecoration? decoration, String? labelText, String? hintText, Widget? prefixIcon, Widget? suffixIcon, bool isPassword = false, FocusNode? focusNode, TextInputAction? textInputAction, bool showCursor = false, ColorModel? labelTextColor, FontWeight? fontWeight}) -
const
Properties
- controller → TextEditingController?
-
final
- decoration → InputDecoration?
-
final
- defaultHorizontalSpace → SizedBox
-
Available on Widget, provided by the WidgetExtension extension
no setter - defaultVerticalSpace → SizedBox
-
Available on Widget, provided by the WidgetExtension extension
no setter - enabled → bool
-
final
- focusNode → FocusNode?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
final
- initialValue → String?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isPassword → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
final
- labelFontSize → double?
-
final
- labelText → String?
-
final
- labelTextColor → ColorModel?
-
final
- maxLength → int?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- obscureText → bool
-
final
-
onChanged
→ VoidCallbackWithValue<
String> ? -
final
-
onFieldSubmitted
→ VoidCallbackWithValue<
String> ? -
final
-
onSaved
→ VoidCallbackWithValue<
String> ? -
final
- onTap → VoidCallback?
-
final
- prefixIcon → Widget?
-
final
- readOnly → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCursor → bool
-
final
- suffixIcon → Widget?
-
final
- textAlign → TextAlign
-
final
- textInputAction → TextInputAction?
-
final
- textStyle → TextStyle?
-
final
- validator → String? Function(String? value)?
-
final
Methods
-
center(
) → Center -
Available on Widget, provided by the WidgetExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TextFieldWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
lightGreyBackground(
{required BuildContext context}) → Container -
Available on Widget, provided by the WidgetExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTap(
GestureTapCallback callback, {VoidCallback? onLongPress}) → InkWell -
Available on Widget, provided by the WidgetExtension extension
-
padAll(
{double? value}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padBottom(
{double? bottom}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padHorizontal(
{double? horizontal}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padLeft(
{double? left}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padRight(
{double? right}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padTop(
{double? top}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padVertical(
{double? vertical}) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
padZero(
) → Padding -
Available on Widget, provided by the WidgetExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
visible(
bool visible, {Widget? defaultWidget}) → Widget -
Available on Widget, provided by the WidgetExtension extension
set visibility
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited