CloseConfig class
Configuration for the optional close button on DynamicMessageWidget.
Constructors
- CloseConfig({bool isCloseAble = false, double? iconSize, void onClose()?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → double?
-
final
- isCloseAble → bool
-
final
- onClose → void Function()?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited