DynamicMsgImageConfig class
Network image block (with placeholder + error fallback) used by DynamicMessageWidget.
Constructors
Properties
- addSpaceToBottom → bool
-
final
- addSpaceToTop → bool
-
final
- boxFit → BoxFit?
-
final
- errorImagePath → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeholderImagePath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited