LabelConfig class
Styling options for a label row inside ValueHighLightWidget.
Constructors
- LabelConfig({String? title, ColorModel? titleFontColor, double? titleFontSize, FontWeight? titleFontWeight, int maxLines = 1})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
final
- titleFontColor → ColorModel?
-
final
- titleFontSize → double?
-
final
- titleFontWeight → FontWeight?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited